# nano-keras

## Overview

### **nano-keras** is a deep learning library written in Python using [NumPy](https://numpy.org/). It's designed to handle the creation and training process of most neural network types, allowing you for quick and easy prototyping and deployment.

### The project is heavily inspired by [Keras](https://keras.io/), the most popular deep learning API in the world, as I'm trying to implement my library in simmilar style and functionality to Keras

## Key Features

### - Simplicity: Built using Python and NumPy, making it easy to read and understand each part

### - Educational: Intended as a learning tool to understand neural network components at a lower level

### - Customization: Allows for tinkering and understanding the core mechanics of neural network operations

## What you can find in nano-keras

### Layers: Dense, Dropout, Reshaping layers, Convolutional layers, Pooling layers and Recurrental Layers

### Optimizers: SGD, Adam, Adadelta, Adagrad, RMSProp, NAdam and much more

### Activation functions: Sigmoid, Tanh, ReLU, ELU, LeakyReLU, Softmax

### Loss functions: MAE, MSE, BCE, CCE, Hinge, Huber

### Callbacks: EarlyStopping, LearningRateScheduler, CSVLogger

### And much more, you can find all the implemented items in [here](https://github.com/MarcelWinterot/nano-keras/wiki/Feature-list)

## Instalation

### **nano-keras** is available on [PyPI](https://pypi.org/project/nano-keras/) so in order to download it open a terminal and paste:

```bash
pip install nano-keras
```

### You now should have succesfully installed nano-keras so to use it in your python file you only need to import it like this:

```py
import nano_keras
```

### If you have an issue message me on github or send me an email

## Documentation

### Documentation is under development and should be finished in the next few days

### You can access it [here](https://github.com/MarcelWinterot/nano-keras/wiki/Documentation)

## License

### This project is licensed under the MIT License - see the LICENSE file for details

## Special thanks

### I'd like to thank my teacher, [Mateusz Kozlowski](https://github.com/mattkozlowski/), who inspired me to start working on this project and kept me motivated to finish this

### Everyone who showed support for me in real life and on LinkedIn

### Without you this project would've never come to life
